import { Subject } from 'rxjs';
import { PickupViewBase } from '@/studio-core';
import EAMAssetService from '@/service/eamasset/eamasset-service';
import EAMAssetAuthService from '@/authservice/eamasset/eamasset-auth-service';
import PickupViewEngine from '@engine/view/pickup-view-engine';
import EAMAssetUIService from '@/uiservice/eamasset/eamasset-ui-service';

/**
 * 资产数据选择视图视图基类
 *
 * @export
 * @class EAMAssetPickupViewBase
 * @extends {PickupViewBase}
 */
export class EAMAssetPickupViewBase extends PickupViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetPickupViewBase
     */
    protected appDeName: string = 'eamasset';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetPickupViewBase
     */
    protected appDeKey: string = 'assetid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetPickupViewBase
     */
    protected appDeMajor: string = 'assetname';

    /**
     * 实体服务对象
     *
     * @type {EAMAssetService}
     * @memberof EAMAssetPickupViewBase
     */
    protected appEntityService: EAMAssetService = new EAMAssetService;

    /**
     * 实体权限服务对象
     *
     * @type EAMAssetUIService
     * @memberof EAMAssetPickupViewBase
     */
    public appUIService: EAMAssetUIService = new EAMAssetUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMAssetPickupViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMAssetPickupViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamasset.views.pickupview.caption',
        srfTitle: 'entities.eamasset.views.pickupview.title',
        srfSubTitle: 'entities.eamasset.views.pickupview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMAssetPickupViewBase
     */
    protected containerModel: any = {
        view_pickupviewpanel: { name: 'pickupviewpanel', type: 'PICKUPVIEWPANEL' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '906130a9861c2b0cff3173c9e171c1d1';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMAssetPickupViewBase
     */
    public engine: PickupViewEngine = new PickupViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMAssetPickupViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            pickupviewpanel: this.$refs.pickupviewpanel,
            keyPSDEField: 'eamasset',
            majorPSDEField: 'assetname',
            isLoadDefault: true,
        });
    }

    /**
     * pickupviewpanel 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetPickupViewBase
     */
    public pickupviewpanel_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'selectionchange', $event);
    }

    /**
     * pickupviewpanel 部件 activated 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetPickupViewBase
     */
    public pickupviewpanel_activated($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'activated', $event);
    }

    /**
     * pickupviewpanel 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetPickupViewBase
     */
    public pickupviewpanel_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'load', $event);
    }


}