import { Subject } from 'rxjs';
import { PickupGridViewBase } from '@/studio-core';
import EAMAssetStateModelService from '@/service/eamasset-state-model/eamasset-state-model-service';
import EAMAssetStateModelAuthService from '@/authservice/eamasset-state-model/eamasset-state-model-auth-service';
import PickupGridViewEngine from '@engine/view/pickup-grid-view-engine';
import EAMAssetStateModelUIService from '@/uiservice/eamasset-state-model/eamasset-state-model-ui-service';

/**
 * 资产状态模型选择表格视图视图基类
 *
 * @export
 * @class EAMAssetStateModelPickupGridViewBase
 * @extends {PickupGridViewBase}
 */
export class EAMAssetStateModelPickupGridViewBase extends PickupGridViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    protected appDeName: string = 'eamassetstatemodel';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    protected appDeKey: string = 'eamassetstatemodelid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    protected appDeMajor: string = 'eamassetstatemodelname';

    /**
     * 实体服务对象
     *
     * @type {EAMAssetStateModelService}
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    protected appEntityService: EAMAssetStateModelService = new EAMAssetStateModelService;

    /**
     * 实体权限服务对象
     *
     * @type EAMAssetStateModelUIService
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    public appUIService: EAMAssetStateModelUIService = new EAMAssetStateModelUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMAssetStateModelPickupGridViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamassetstatemodel.views.pickupgridview.caption',
        srfTitle: 'entities.eamassetstatemodel.views.pickupgridview.title',
        srfSubTitle: 'entities.eamassetstatemodel.views.pickupgridview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    protected containerModel: any = {
        view_grid: { name: 'grid', type: 'GRID' },
        view_searchform: { name: 'searchform', type: 'SEARCHFORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'a9f86b6e01c06082f119369de0ee8f01';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    public engine: PickupGridViewEngine = new PickupGridViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            grid: this.$refs.grid,
            searchform: this.$refs.searchform,
            keyPSDEField: 'eamassetstatemodel',
            majorPSDEField: 'eamassetstatemodelname',
            isLoadDefault: true,
        });
    }

    /**
     * grid 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    public grid_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'selectionchange', $event);
    }

    /**
     * grid 部件 beforeload 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    public grid_beforeload($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'beforeload', $event);
    }

    /**
     * grid 部件 rowdblclick 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    public grid_rowdblclick($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'rowdblclick', $event);
    }

    /**
     * grid 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    public grid_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'load', $event);
    }

    /**
     * searchform 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    public searchform_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'save', $event);
    }

    /**
     * searchform 部件 search 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    public searchform_search($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'search', $event);
    }

    /**
     * searchform 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    public searchform_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'load', $event);
    }



    /**
     * 是否展开搜索表单
     *
     * @protected
     * @type {boolean}
     * @memberof EAMAssetStateModelPickupGridViewBase
     */
    protected isExpandSearchForm: boolean = true;


}