import { Subject } from 'rxjs';
import { PickupViewBase } from '@/studio-core';
import EAMAssetStateModelService from '@/service/eamasset-state-model/eamasset-state-model-service';
import EAMAssetStateModelAuthService from '@/authservice/eamasset-state-model/eamasset-state-model-auth-service';
import PickupViewEngine from '@engine/view/pickup-view-engine';
import EAMAssetStateModelUIService from '@/uiservice/eamasset-state-model/eamasset-state-model-ui-service';

/**
 * 资产状态模型数据选择视图视图基类
 *
 * @export
 * @class EAMAssetStateModelPickupViewBase
 * @extends {PickupViewBase}
 */
export class EAMAssetStateModelPickupViewBase extends PickupViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetStateModelPickupViewBase
     */
    protected appDeName: string = 'eamassetstatemodel';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetStateModelPickupViewBase
     */
    protected appDeKey: string = 'eamassetstatemodelid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetStateModelPickupViewBase
     */
    protected appDeMajor: string = 'eamassetstatemodelname';

    /**
     * 实体服务对象
     *
     * @type {EAMAssetStateModelService}
     * @memberof EAMAssetStateModelPickupViewBase
     */
    protected appEntityService: EAMAssetStateModelService = new EAMAssetStateModelService;

    /**
     * 实体权限服务对象
     *
     * @type EAMAssetStateModelUIService
     * @memberof EAMAssetStateModelPickupViewBase
     */
    public appUIService: EAMAssetStateModelUIService = new EAMAssetStateModelUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMAssetStateModelPickupViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMAssetStateModelPickupViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamassetstatemodel.views.pickupview.caption',
        srfTitle: 'entities.eamassetstatemodel.views.pickupview.title',
        srfSubTitle: 'entities.eamassetstatemodel.views.pickupview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMAssetStateModelPickupViewBase
     */
    protected containerModel: any = {
        view_pickupviewpanel: { name: 'pickupviewpanel', type: 'PICKUPVIEWPANEL' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'd69c20799b79d71f84ed52f036b3490c';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMAssetStateModelPickupViewBase
     */
    public engine: PickupViewEngine = new PickupViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMAssetStateModelPickupViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            pickupviewpanel: this.$refs.pickupviewpanel,
            keyPSDEField: 'eamassetstatemodel',
            majorPSDEField: 'eamassetstatemodelname',
            isLoadDefault: true,
        });
    }

    /**
     * pickupviewpanel 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetStateModelPickupViewBase
     */
    public pickupviewpanel_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'selectionchange', $event);
    }

    /**
     * pickupviewpanel 部件 activated 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetStateModelPickupViewBase
     */
    public pickupviewpanel_activated($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'activated', $event);
    }

    /**
     * pickupviewpanel 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetStateModelPickupViewBase
     */
    public pickupviewpanel_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'load', $event);
    }


}