import { Subject } from 'rxjs';
import { EditViewBase } from '@/studio-core';
import EAMAssetTypeService from '@/service/eamasset-type/eamasset-type-service';
import EAMAssetTypeAuthService from '@/authservice/eamasset-type/eamasset-type-auth-service';
import EditViewEngine from '@engine/view/edit-view-engine';
import EAMAssetTypeUIService from '@/uiservice/eamasset-type/eamasset-type-ui-service';

/**
 * 资产类型主信息视图基类
 *
 * @export
 * @class EAMAssetTypeInfo_MainViewBase
 * @extends {EditViewBase}
 */
export class EAMAssetTypeInfo_MainViewBase extends EditViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetTypeInfo_MainViewBase
     */
    protected appDeName: string = 'eamassettype';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetTypeInfo_MainViewBase
     */
    protected appDeKey: string = 'eamassettypeid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetTypeInfo_MainViewBase
     */
    protected appDeMajor: string = 'eamassettypename';

    /**
     * 实体服务对象
     *
     * @type {EAMAssetTypeService}
     * @memberof EAMAssetTypeInfo_MainViewBase
     */
    protected appEntityService: EAMAssetTypeService = new EAMAssetTypeService;

    /**
     * 实体权限服务对象
     *
     * @type EAMAssetTypeUIService
     * @memberof EAMAssetTypeInfo_MainViewBase
     */
    public appUIService: EAMAssetTypeUIService = new EAMAssetTypeUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMAssetTypeInfo_MainViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMAssetTypeInfo_MainViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamassettype.views.info_mainview.caption',
        srfTitle: 'entities.eamassettype.views.info_mainview.title',
        srfSubTitle: 'entities.eamassettype.views.info_mainview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMAssetTypeInfo_MainViewBase
     */
    protected containerModel: any = {
        view_form: { name: 'form', type: 'FORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '0f5279839c91bc31fde9eebfa1b00f36';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMAssetTypeInfo_MainViewBase
     */
    public engine: EditViewEngine = new EditViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMAssetTypeInfo_MainViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            form: this.$refs.form,
            p2k: '0',
            keyPSDEField: 'eamassettype',
            majorPSDEField: 'eamassettypename',
            isLoadDefault: true,
        });
    }

    /**
     * form 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetTypeInfo_MainViewBase
     */
    public form_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'save', $event);
    }

    /**
     * form 部件 remove 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetTypeInfo_MainViewBase
     */
    public form_remove($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'remove', $event);
    }

    /**
     * form 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetTypeInfo_MainViewBase
     */
    public form_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'load', $event);
    }


}