import { Subject } from 'rxjs';
import { TabExpViewBase } from '@/studio-core';
import EAMAssetTypeService from '@/service/eamasset-type/eamasset-type-service';
import EAMAssetTypeAuthService from '@/authservice/eamasset-type/eamasset-type-auth-service';
import TabExpViewEngine from '@engine/view/tab-exp-view-engine';
import EAMAssetTypeUIService from '@/uiservice/eamasset-type/eamasset-type-ui-service';

/**
 * 资产类型信息视图基类
 *
 * @export
 * @class EAMAssetTypeInfoViewBase
 * @extends {TabExpViewBase}
 */
export class EAMAssetTypeInfoViewBase extends TabExpViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetTypeInfoViewBase
     */
    protected appDeName: string = 'eamassettype';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetTypeInfoViewBase
     */
    protected appDeKey: string = 'eamassettypeid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetTypeInfoViewBase
     */
    protected appDeMajor: string = 'eamassettypename';

    /**
     * 实体服务对象
     *
     * @type {EAMAssetTypeService}
     * @memberof EAMAssetTypeInfoViewBase
     */
    protected appEntityService: EAMAssetTypeService = new EAMAssetTypeService;

    /**
     * 实体权限服务对象
     *
     * @type EAMAssetTypeUIService
     * @memberof EAMAssetTypeInfoViewBase
     */
    public appUIService: EAMAssetTypeUIService = new EAMAssetTypeUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMAssetTypeInfoViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMAssetTypeInfoViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamassettype.views.infoview.caption',
        srfTitle: 'entities.eamassettype.views.infoview.title',
        srfSubTitle: 'entities.eamassettype.views.infoview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMAssetTypeInfoViewBase
     */
    protected containerModel: any = {
        view_tabexppanel: { name: 'tabexppanel', type: 'TABEXPPANEL' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '0a6cec446cd7b36771eccacdf2ce4b54';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMAssetTypeInfoViewBase
     */
    public engine: TabExpViewEngine = new TabExpViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMAssetTypeInfoViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            keyPSDEField: 'eamassettype',
            majorPSDEField: 'eamassettypename',
            isLoadDefault: true,
        });
    }


}