import { Subject } from 'rxjs';
import { DashboardViewBase } from '@/studio-core';
import EAMAssetTypeService from '@/service/eamasset-type/eamasset-type-service';
import EAMAssetTypeAuthService from '@/authservice/eamasset-type/eamasset-type-auth-service';
import PortalViewEngine from '@engine/view/portal-view-engine';
import EAMAssetTypeUIService from '@/uiservice/eamasset-type/eamasset-type-ui-service';

/**
 * 资产类型主信息看板视图基类
 *
 * @export
 * @class EAMAssetTypeSummaryViewBase
 * @extends {DashboardViewBase}
 */
export class EAMAssetTypeSummaryViewBase extends DashboardViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetTypeSummaryViewBase
     */
    protected appDeName: string = 'eamassettype';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetTypeSummaryViewBase
     */
    protected appDeKey: string = 'eamassettypeid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetTypeSummaryViewBase
     */
    protected appDeMajor: string = 'eamassettypename';

    /**
     * 实体服务对象
     *
     * @type {EAMAssetTypeService}
     * @memberof EAMAssetTypeSummaryViewBase
     */
    protected appEntityService: EAMAssetTypeService = new EAMAssetTypeService;

    /**
     * 实体权限服务对象
     *
     * @type EAMAssetTypeUIService
     * @memberof EAMAssetTypeSummaryViewBase
     */
    public appUIService: EAMAssetTypeUIService = new EAMAssetTypeUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMAssetTypeSummaryViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMAssetTypeSummaryViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamassettype.views.summaryview.caption',
        srfTitle: 'entities.eamassettype.views.summaryview.title',
        srfSubTitle: 'entities.eamassettype.views.summaryview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMAssetTypeSummaryViewBase
     */
    protected containerModel: any = {
        view_dashboard: { name: 'dashboard', type: 'DASHBOARD' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'e82ae69965b5b61347246f54ab96dc6f';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMAssetTypeSummaryViewBase
     */
    public engine: PortalViewEngine = new PortalViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMAssetTypeSummaryViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            dashboard: this.$refs.dashboard,
            keyPSDEField: 'eamassettype',
            majorPSDEField: 'eamassettypename',
            isLoadDefault: true,
        });
    }

    /**
     * dashboard 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetTypeSummaryViewBase
     */
    public dashboard_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('dashboard', 'load', $event);
    }


}