import { Subject } from 'rxjs';
import { PickupGridViewBase } from '@/studio-core';
import EAMDocumentTypeService from '@/service/eamdocument-type/eamdocument-type-service';
import EAMDocumentTypeAuthService from '@/authservice/eamdocument-type/eamdocument-type-auth-service';
import PickupGridViewEngine from '@engine/view/pickup-grid-view-engine';
import EAMDocumentTypeUIService from '@/uiservice/eamdocument-type/eamdocument-type-ui-service';

/**
 * 文档类型选择表格视图视图基类
 *
 * @export
 * @class EAMDocumentTypePickupGridViewBase
 * @extends {PickupGridViewBase}
 */
export class EAMDocumentTypePickupGridViewBase extends PickupGridViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    protected appDeName: string = 'eamdocumenttype';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    protected appDeKey: string = 'eamdocumenttypeid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    protected appDeMajor: string = 'eamdocumenttypename';

    /**
     * 实体服务对象
     *
     * @type {EAMDocumentTypeService}
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    protected appEntityService: EAMDocumentTypeService = new EAMDocumentTypeService;

    /**
     * 实体权限服务对象
     *
     * @type EAMDocumentTypeUIService
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    public appUIService: EAMDocumentTypeUIService = new EAMDocumentTypeUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMDocumentTypePickupGridViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamdocumenttype.views.pickupgridview.caption',
        srfTitle: 'entities.eamdocumenttype.views.pickupgridview.title',
        srfSubTitle: 'entities.eamdocumenttype.views.pickupgridview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    protected containerModel: any = {
        view_grid: { name: 'grid', type: 'GRID' },
        view_searchform: { name: 'searchform', type: 'SEARCHFORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '8dad4ab59adf6e7eb152878eb283da71';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    public engine: PickupGridViewEngine = new PickupGridViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            grid: this.$refs.grid,
            searchform: this.$refs.searchform,
            keyPSDEField: 'eamdocumenttype',
            majorPSDEField: 'eamdocumenttypename',
            isLoadDefault: true,
        });
    }

    /**
     * grid 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    public grid_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'selectionchange', $event);
    }

    /**
     * grid 部件 beforeload 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    public grid_beforeload($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'beforeload', $event);
    }

    /**
     * grid 部件 rowdblclick 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    public grid_rowdblclick($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'rowdblclick', $event);
    }

    /**
     * grid 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    public grid_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'load', $event);
    }

    /**
     * searchform 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    public searchform_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'save', $event);
    }

    /**
     * searchform 部件 search 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    public searchform_search($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'search', $event);
    }

    /**
     * searchform 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    public searchform_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'load', $event);
    }



    /**
     * 是否展开搜索表单
     *
     * @protected
     * @type {boolean}
     * @memberof EAMDocumentTypePickupGridViewBase
     */
    protected isExpandSearchForm: boolean = true;


}