import { Subject } from 'rxjs';
import { PickupViewBase } from '@/studio-core';
import EAMDocumentTypeService from '@/service/eamdocument-type/eamdocument-type-service';
import EAMDocumentTypeAuthService from '@/authservice/eamdocument-type/eamdocument-type-auth-service';
import PickupViewEngine from '@engine/view/pickup-view-engine';
import EAMDocumentTypeUIService from '@/uiservice/eamdocument-type/eamdocument-type-ui-service';

/**
 * 文档类型数据选择视图视图基类
 *
 * @export
 * @class EAMDocumentTypePickupViewBase
 * @extends {PickupViewBase}
 */
export class EAMDocumentTypePickupViewBase extends PickupViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMDocumentTypePickupViewBase
     */
    protected appDeName: string = 'eamdocumenttype';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMDocumentTypePickupViewBase
     */
    protected appDeKey: string = 'eamdocumenttypeid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMDocumentTypePickupViewBase
     */
    protected appDeMajor: string = 'eamdocumenttypename';

    /**
     * 实体服务对象
     *
     * @type {EAMDocumentTypeService}
     * @memberof EAMDocumentTypePickupViewBase
     */
    protected appEntityService: EAMDocumentTypeService = new EAMDocumentTypeService;

    /**
     * 实体权限服务对象
     *
     * @type EAMDocumentTypeUIService
     * @memberof EAMDocumentTypePickupViewBase
     */
    public appUIService: EAMDocumentTypeUIService = new EAMDocumentTypeUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMDocumentTypePickupViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMDocumentTypePickupViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamdocumenttype.views.pickupview.caption',
        srfTitle: 'entities.eamdocumenttype.views.pickupview.title',
        srfSubTitle: 'entities.eamdocumenttype.views.pickupview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMDocumentTypePickupViewBase
     */
    protected containerModel: any = {
        view_pickupviewpanel: { name: 'pickupviewpanel', type: 'PICKUPVIEWPANEL' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'd7f78755bc3c9a5855de8a2fc67e668e';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMDocumentTypePickupViewBase
     */
    public engine: PickupViewEngine = new PickupViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMDocumentTypePickupViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            pickupviewpanel: this.$refs.pickupviewpanel,
            keyPSDEField: 'eamdocumenttype',
            majorPSDEField: 'eamdocumenttypename',
            isLoadDefault: true,
        });
    }

    /**
     * pickupviewpanel 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMDocumentTypePickupViewBase
     */
    public pickupviewpanel_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'selectionchange', $event);
    }

    /**
     * pickupviewpanel 部件 activated 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMDocumentTypePickupViewBase
     */
    public pickupviewpanel_activated($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'activated', $event);
    }

    /**
     * pickupviewpanel 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMDocumentTypePickupViewBase
     */
    public pickupviewpanel_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'load', $event);
    }


}