import { Subject } from 'rxjs';
import { EditViewBase } from '@/studio-core';
import EAMSparePartsGroupService from '@/service/eamspare-parts-group/eamspare-parts-group-service';
import EAMSparePartsGroupAuthService from '@/authservice/eamspare-parts-group/eamspare-parts-group-auth-service';
import EditViewEngine from '@engine/view/edit-view-engine';
import EAMSparePartsGroupUIService from '@/uiservice/eamspare-parts-group/eamspare-parts-group-ui-service';

/**
 * 备件包信息视图基类
 *
 * @export
 * @class EAMSparePartsGroupInfo_MainViewBase
 * @extends {EditViewBase}
 */
export class EAMSparePartsGroupInfo_MainViewBase extends EditViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMSparePartsGroupInfo_MainViewBase
     */
    protected appDeName: string = 'eamsparepartsgroup';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMSparePartsGroupInfo_MainViewBase
     */
    protected appDeKey: string = 'eamsparepartsgroupid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMSparePartsGroupInfo_MainViewBase
     */
    protected appDeMajor: string = 'eamsparepartsgroupname';

    /**
     * 实体服务对象
     *
     * @type {EAMSparePartsGroupService}
     * @memberof EAMSparePartsGroupInfo_MainViewBase
     */
    protected appEntityService: EAMSparePartsGroupService = new EAMSparePartsGroupService;

    /**
     * 实体权限服务对象
     *
     * @type EAMSparePartsGroupUIService
     * @memberof EAMSparePartsGroupInfo_MainViewBase
     */
    public appUIService: EAMSparePartsGroupUIService = new EAMSparePartsGroupUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMSparePartsGroupInfo_MainViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMSparePartsGroupInfo_MainViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamsparepartsgroup.views.info_mainview.caption',
        srfTitle: 'entities.eamsparepartsgroup.views.info_mainview.title',
        srfSubTitle: 'entities.eamsparepartsgroup.views.info_mainview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMSparePartsGroupInfo_MainViewBase
     */
    protected containerModel: any = {
        view_form: { name: 'form', type: 'FORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '9e6a4acf7233f5e1643cbbc7509480b6';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMSparePartsGroupInfo_MainViewBase
     */
    public engine: EditViewEngine = new EditViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMSparePartsGroupInfo_MainViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            form: this.$refs.form,
            p2k: '0',
            keyPSDEField: 'eamsparepartsgroup',
            majorPSDEField: 'eamsparepartsgroupname',
            isLoadDefault: true,
        });
    }

    /**
     * form 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMSparePartsGroupInfo_MainViewBase
     */
    public form_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'save', $event);
    }

    /**
     * form 部件 remove 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMSparePartsGroupInfo_MainViewBase
     */
    public form_remove($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'remove', $event);
    }

    /**
     * form 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMSparePartsGroupInfo_MainViewBase
     */
    public form_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'load', $event);
    }


}