import { Subject } from 'rxjs';
import { PickupGridViewBase } from '@/studio-core';
import EAMSparePartsGroupService from '@/service/eamspare-parts-group/eamspare-parts-group-service';
import EAMSparePartsGroupAuthService from '@/authservice/eamspare-parts-group/eamspare-parts-group-auth-service';
import PickupGridViewEngine from '@engine/view/pickup-grid-view-engine';
import EAMSparePartsGroupUIService from '@/uiservice/eamspare-parts-group/eamspare-parts-group-ui-service';

/**
 * 备件包选择表格视图视图基类
 *
 * @export
 * @class EAMSparePartsGroupPickupGridViewBase
 * @extends {PickupGridViewBase}
 */
export class EAMSparePartsGroupPickupGridViewBase extends PickupGridViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    protected appDeName: string = 'eamsparepartsgroup';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    protected appDeKey: string = 'eamsparepartsgroupid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    protected appDeMajor: string = 'eamsparepartsgroupname';

    /**
     * 实体服务对象
     *
     * @type {EAMSparePartsGroupService}
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    protected appEntityService: EAMSparePartsGroupService = new EAMSparePartsGroupService;

    /**
     * 实体权限服务对象
     *
     * @type EAMSparePartsGroupUIService
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    public appUIService: EAMSparePartsGroupUIService = new EAMSparePartsGroupUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamsparepartsgroup.views.pickupgridview.caption',
        srfTitle: 'entities.eamsparepartsgroup.views.pickupgridview.title',
        srfSubTitle: 'entities.eamsparepartsgroup.views.pickupgridview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    protected containerModel: any = {
        view_grid: { name: 'grid', type: 'GRID' },
        view_searchform: { name: 'searchform', type: 'SEARCHFORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'ebf6c093d1d6c599cc011b2c54ab6bc2';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    public engine: PickupGridViewEngine = new PickupGridViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            grid: this.$refs.grid,
            searchform: this.$refs.searchform,
            keyPSDEField: 'eamsparepartsgroup',
            majorPSDEField: 'eamsparepartsgroupname',
            isLoadDefault: true,
        });
    }

    /**
     * grid 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    public grid_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'selectionchange', $event);
    }

    /**
     * grid 部件 beforeload 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    public grid_beforeload($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'beforeload', $event);
    }

    /**
     * grid 部件 rowdblclick 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    public grid_rowdblclick($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'rowdblclick', $event);
    }

    /**
     * grid 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    public grid_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'load', $event);
    }

    /**
     * searchform 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    public searchform_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'save', $event);
    }

    /**
     * searchform 部件 search 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    public searchform_search($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'search', $event);
    }

    /**
     * searchform 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    public searchform_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'load', $event);
    }



    /**
     * 是否展开搜索表单
     *
     * @protected
     * @type {boolean}
     * @memberof EAMSparePartsGroupPickupGridViewBase
     */
    protected isExpandSearchForm: boolean = true;


}