import { Subject } from 'rxjs';
import { PickupViewBase } from '@/studio-core';
import EAMSparePartsGroupService from '@/service/eamspare-parts-group/eamspare-parts-group-service';
import EAMSparePartsGroupAuthService from '@/authservice/eamspare-parts-group/eamspare-parts-group-auth-service';
import PickupViewEngine from '@engine/view/pickup-view-engine';
import EAMSparePartsGroupUIService from '@/uiservice/eamspare-parts-group/eamspare-parts-group-ui-service';

/**
 * 备件包数据选择视图视图基类
 *
 * @export
 * @class EAMSparePartsGroupPickupViewBase
 * @extends {PickupViewBase}
 */
export class EAMSparePartsGroupPickupViewBase extends PickupViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMSparePartsGroupPickupViewBase
     */
    protected appDeName: string = 'eamsparepartsgroup';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMSparePartsGroupPickupViewBase
     */
    protected appDeKey: string = 'eamsparepartsgroupid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMSparePartsGroupPickupViewBase
     */
    protected appDeMajor: string = 'eamsparepartsgroupname';

    /**
     * 实体服务对象
     *
     * @type {EAMSparePartsGroupService}
     * @memberof EAMSparePartsGroupPickupViewBase
     */
    protected appEntityService: EAMSparePartsGroupService = new EAMSparePartsGroupService;

    /**
     * 实体权限服务对象
     *
     * @type EAMSparePartsGroupUIService
     * @memberof EAMSparePartsGroupPickupViewBase
     */
    public appUIService: EAMSparePartsGroupUIService = new EAMSparePartsGroupUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMSparePartsGroupPickupViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMSparePartsGroupPickupViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamsparepartsgroup.views.pickupview.caption',
        srfTitle: 'entities.eamsparepartsgroup.views.pickupview.title',
        srfSubTitle: 'entities.eamsparepartsgroup.views.pickupview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMSparePartsGroupPickupViewBase
     */
    protected containerModel: any = {
        view_pickupviewpanel: { name: 'pickupviewpanel', type: 'PICKUPVIEWPANEL' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '81139a9fb0fce24a58db188651ba7155';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMSparePartsGroupPickupViewBase
     */
    public engine: PickupViewEngine = new PickupViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMSparePartsGroupPickupViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            pickupviewpanel: this.$refs.pickupviewpanel,
            keyPSDEField: 'eamsparepartsgroup',
            majorPSDEField: 'eamsparepartsgroupname',
            isLoadDefault: true,
        });
    }

    /**
     * pickupviewpanel 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMSparePartsGroupPickupViewBase
     */
    public pickupviewpanel_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'selectionchange', $event);
    }

    /**
     * pickupviewpanel 部件 activated 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMSparePartsGroupPickupViewBase
     */
    public pickupviewpanel_activated($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'activated', $event);
    }

    /**
     * pickupviewpanel 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMSparePartsGroupPickupViewBase
     */
    public pickupviewpanel_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'load', $event);
    }


}